==> jc-1.4.0.tar.gz: java/util/AbstractMap__242__241.h <==
// final class java.util.AbstractMap$2$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9c208a9965328ec0 java_util_AbstractMap__242__241

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_AbstractMap__242__241_H_
#define _JC_java_util_AbstractMap__242__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_AbstractMap__242$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_util_AbstractMap__242__241$sub_refs	_jc_java_util_AbstractMap__242__241$sub_refs;
typedef struct _jc_java_util_AbstractMap__242__241$sub_nonrefs	_jc_java_util_AbstractMap__242__241$sub_nonrefs;
typedef struct _jc_java_util_AbstractMap__242__241$refs	_jc_java_util_AbstractMap__242__241$refs;
typedef struct _jc_java_util_AbstractMap__242__241$nonrefs	_jc_java_util_AbstractMap__242__241$nonrefs;
typedef struct _jc_java_util_AbstractMap__242__241$object	_jc_java_util_AbstractMap__242__241$object;

typedef const struct _jc_java_util_AbstractMap__242__241$vmethods	_jc_java_util_AbstractMap__242__241$vmethods;
typedef const struct _jc_java_util_AbstractMap__242__241$vtable	_jc_java_util_AbstractMap__242__241$vtable;
typedef const struct _jc_java_util_AbstractMap__242__241$vtype	_jc_java_util_AbstractMap__242__241$vtype;

// Constructors
extern void _jc_java_util_AbstractMap__242__241$method$_init$fc1d4984754a3ad0(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *, struct _jc_java_util_AbstractMap__242$object *);

// Virtual methods
extern jboolean _jc_java_util_AbstractMap__242__241$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_AbstractMap__242__241$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *);
extern void _jc_java_util_AbstractMap__242__241$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *);
extern void _jc_java_util_AbstractMap__242__241$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_AbstractMap__242__241$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_java_util_AbstractMap__242__241$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_java_util_AbstractMap__242__241$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_java_util_AbstractMap__242__241$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_AbstractMap__242__241$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *);
};

// Vtable
struct _jc_java_util_AbstractMap__242__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap__242__241$vmethods	java_util_AbstractMap__242__241;
};

// Vtype
struct _jc_java_util_AbstractMap__242__241$vtype {
	_jc_type			type;
	_jc_java_util_AbstractMap__242__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_AbstractMap__242__241$sub_refs {
	struct _jc_object	*map__5fiterator;
	struct _jc_java_util_AbstractMap__242$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_AbstractMap__242__241$refs {
    _jc_java_util_AbstractMap__242__241$sub_refs	java_util_AbstractMap__242__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_AbstractMap__242__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_AbstractMap__242__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap__242__241$sub_nonrefs	java_util_AbstractMap__242__241;
};

// Object instance structure
struct _jc_java_util_AbstractMap__242__241$object {
	_jc_java_util_AbstractMap__242__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_AbstractMap__242__241$vtype	*vtype;
	_jc_java_util_AbstractMap__242__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_AbstractMap__242__241$vtype _jc_java_util_AbstractMap__242__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_AbstractMap__242__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_AbstractMap__242__241$class_object;

#endif	/* _JC_java_util_AbstractMap__242__241_H_ */

==> jc-1.4.6.tar.gz: java/util/AbstractMap__242__241.h <==
// final class java.util.AbstractMap$2$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9c208a9965328ec0 java_util_AbstractMap__242__241

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_AbstractMap__242__241_H_
#define _JC_java_util_AbstractMap__242__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_AbstractMap__242$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_util_AbstractMap__242__241$sub_refs	_jc_java_util_AbstractMap__242__241$sub_refs;
typedef struct _jc_java_util_AbstractMap__242__241$sub_nonrefs	_jc_java_util_AbstractMap__242__241$sub_nonrefs;
typedef struct _jc_java_util_AbstractMap__242__241$refs	_jc_java_util_AbstractMap__242__241$refs;
typedef struct _jc_java_util_AbstractMap__242__241$nonrefs	_jc_java_util_AbstractMap__242__241$nonrefs;
typedef struct _jc_java_util_AbstractMap__242__241$object	_jc_java_util_AbstractMap__242__241$object;

typedef const struct _jc_java_util_AbstractMap__242__241$vmethods	_jc_java_util_AbstractMap__242__241$vmethods;
typedef const struct _jc_java_util_AbstractMap__242__241$vtable	_jc_java_util_AbstractMap__242__241$vtable;
typedef const struct _jc_java_util_AbstractMap__242__241$vtype	_jc_java_util_AbstractMap__242__241$vtype;

// Constructors
extern void _jc_java_util_AbstractMap__242__241$method$_init$fc1d4984754a3ad0(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *, struct _jc_java_util_AbstractMap__242$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_AbstractMap__242__241$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_AbstractMap__242__241$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_AbstractMap__242__241$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_AbstractMap__242__241$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_AbstractMap__242__241$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_java_util_AbstractMap__242__241$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_java_util_AbstractMap__242__241$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_java_util_AbstractMap__242__241$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_AbstractMap__242__241$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_AbstractMap__242__241$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_AbstractMap__242__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap__242__241$vmethods	java_util_AbstractMap__242__241;
};

// Vtype
struct _jc_java_util_AbstractMap__242__241$vtype {
	_jc_type			type;
	_jc_java_util_AbstractMap__242__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_AbstractMap__242__241$sub_refs {
	struct _jc_object	*map__5fiterator;
	struct _jc_java_util_AbstractMap__242$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_AbstractMap__242__241$refs {
    _jc_java_util_AbstractMap__242__241$sub_refs	java_util_AbstractMap__242__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_AbstractMap__242__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_AbstractMap__242__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap__242__241$sub_nonrefs	java_util_AbstractMap__242__241;
};

// Object instance structure
struct _jc_java_util_AbstractMap__242__241$object {
	_jc_java_util_AbstractMap__242__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_AbstractMap__242__241$vtype	*vtype;
	_jc_java_util_AbstractMap__242__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_AbstractMap__242__241$vtype _jc_java_util_AbstractMap__242__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_AbstractMap__242__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_AbstractMap__242__241$class_object;

#endif	/* _JC_java_util_AbstractMap__242__241_H_ */
